#-*- mode: makefile; tab-width: 4; -*
# ex:ts=4
#
# New ports collection makefile for:	vim-scripts infrastructure
# Date created:		16 September 2007
# Whom:				Andrew Pantyukhin <infofarmer@FreeBSD.org>
#
# $FreeBSD$
#

# VIM_SCRIPT_ID	- Script ID on http://vim.sourceforge.net/scripts/. Only needed
# 				  for maintenance purposes, like creating a new port and checking
# 				  for new versions.
# VIM_SRC_ID	- Source ID on http://vim.sourceforge.net/scripts/
# VIM_FILES		- List of files. This is used to produce PLIST_FILES. VIM_FILES
#				  can be generated by vim-gen.
# PORTNAME, PORTVERSION, CATEGORIES, MAINTAINER, COMMENT
#				- These should all be set manually for port to be functional. See
#				  ${PORTSDIR}/Mk/bsd.port.mk for details. It can make sense to
#				  include ${VIM_SRC_ID} in ${PORTVERSION}.
# MASTER_SITES	- This should be set if port is unavailable at the default site.
#				  Default: CENKES/myports/vim-scripts
# VIM_LIBDIR	- Name of the directory to install extensions in.
#				  Default: ${PREFIX}/share/vim/vimfiles
# VIM_FTDETECT	- Filetype detection. Triples in the form of
# 				  <mechanism>:<filetype>:<args>. For example, path:text:*.txt.
# 				  Only path mechanism is supported for now.
# 				  Default: empty
#
# This Makefile is an alpha-version of the vim scripts infrastructure.
#
# A new vim-script will require a PORTNAME, PORTVERSION, and CATEGORIES. In
# case it is not published at CENKES, MASTER_SITES can be redefined.  VIM_*
# vars will also need to be defined manually, which helps keep the
# infrastructure simpler.
#

.ifndef MASTER_SITES
MASTER_SITES?=	CENKES/myports/vim-scripts
USE_BZIP2=		yes
.endif
PKGNAMEPREFIX?=	vim-
DISTNAME?=		srcid-${VIM_SRC_ID}
DIST_SUBDIR?=	vim-scripts
VIM_LIBDIR?=	${PREFIX}/share/vim/vimfiles
VIM_FILES+=		${VIM_FTDETECT:C/[^:]*://:C/:.*//:S|^|ftdetect/|:S|$|.vim|}
PLIST_SUB+=		VIM_LIBDIR="${VIM_LIBDIR:S,^${PREFIX}/,,}"
PLIST_FILES+=	${VIM_FILES:S!^!%%VIM_LIBDIR%%/!}

_A=	>> ${TMPPLIST}
_Q=	2>/dev/null || true

.if !target(do-build)
do-build:
.ifdef VIM_FTDETECT
	@${MKDIR} ${WRKSRC}/ftdetect/
	@for i in ${VIM_FTDETECT:Mpath\:*:C/[^:]*://};do\
		${ECHO_CMD} "au BufRead,BufNewFile $${i#*:} setf $${i%%:*}"\
		>${WRKSRC}/ftdetect/$${i%%:*}.vim;done
.endif
.endif

.if !target(do-install)
do-install:
	@cd ${WRKSRC}/&&${COPYTREE_SHARE} . ${VIM_LIBDIR}/
	@${ECHO_CMD} '@unexec cd ${VIM_LIBDIR:S,^${PREFIX}/,%D/,}/&&\
	rmdir -p ${VIM_FILES:M*/*:C|/[^/]*$||} ${_Q}' ${_A};done
	@${ECHO_CMD} '@unexec cd %D/&&rmdir ${VIM_LIBDIR:S,^${PREFIX}/,,} share/vim\
		${_Q}' ${_A}
.endif

# Maintainer section
vim-gen:	extract
	@${ECHO_CMD} -n 'VIM_FILES='
	@cd ${WRKSRC} && ${FIND} -s . -not -type d | cut -f2- -d/ | ${TR} '\n' ' '

vim-plist:	extract
	@${FIND} -s ${WRKSRC} -not -type d | ${SED} -e "s,^${WRKSRC},%%VIM_LIBDIR%%," > ${PLIST}
	@${FIND} -ds ${WRKSRC} -type d -not -name ${DISTNAME} | \
		${SED} -e "s,^${WRKSRC},@dirrmtry %%VIM_LIBDIR%%," >> ${PLIST}
